# -*- coding: utf-8 -*-
import sys


class ProcessInformation():
    def __init__(self):
        list = []
        str1 = '新疆：乌鲁木齐、克拉玛依、石河子、阿拉尔市、图木舒克、巴音郭楞、伊宁市、五家渠、哈密、吐鲁番、阿克苏、喀什、和田、伊宁、塔城、阿勒泰、奎屯、博乐市、昌吉、阜康、库尔勒、阿图什市、乌苏'
        str2 = '西藏：拉萨、日喀则'
        str3 = '宁夏：银川、石嘴山、吴忠、固原、中卫、青铜峡市、灵武市'
        str4 = '内蒙古：呼和浩特、包头、乌海、巴彦淖尔市、赤峰、通辽、鄂尔多斯、呼伦贝尔、巴彦淖尔、乌兰察布、霍林郭勒市、海拉尔、满洲里市、牙克石市、扎兰屯市、根河市、额尔古纳市、丰镇市、锡林浩特市、二连浩特市、乌兰浩特市、阿尔山市'
        str5 = '广西：南宁、柳州、桂林、梧州、北海、崇左、来宾、贺州、玉林、百色、河池、钦州、防城港、贵港、岑溪市、凭祥、合山市、北流市、宜州市、东兴、桂平'
        str6 = '黑龙江：哈尔滨、大庆、齐齐哈尔、佳木斯、鸡西、鹤岗、双鸭山、牡丹江、伊春、七台河、黑河、绥化、五常、双城、尚志、纳河、虎林、密山市、铁力市、同江、富锦、绥芬河市、讷河、海林、宁安市、穆林、北安市、五大连池、肇东、海伦、安达'
        str7 = '吉林：长春、吉林、四平、辽源、通化、白山、松原、白城、九台市、榆树市、德惠市、舒兰市、桦甸市、安图县、蛟河市、磐石市、公主岭市、双辽市、梅河口市、集安市、临江市、大安市、洮南市、延吉市、图们市、敦化市、龙井市、珲春市、和龙市'
        str8 = "辽宁：沈阳、大连、鞍山、抚顺、本溪、丹东、锦州、营口、兴城市、阜新、辽阳、盘锦、铁岭、朝阳、葫芦岛、新民、瓦房店、普兰、庄河、海城、东港、凤城、凌海、北镇、大石桥、盖州、灯塔市、调兵山、开原、凌源、北票市、兴城"
        str9 = '河北：石家庄、唐山、邯郸、秦皇岛、保定、张家口、承德、廊坊、沧州、衡水、邢台、辛集市、藁城市、晋州市、赵县、新乐市、鹿泉市、遵化市、迁安市、武安市、南宫市、沙河市、涿州市、定州市、安国市、高碑店市、泊头市、任丘市、黄骅市、河间市、霸州市、三河市、冀州市、深州市'
        str10 = '山东：济南、青岛、淄博、枣庄、东营、烟台、潍坊、济宁、寿光、新泰、泰安、威海、日照、荣成市、莱芜、乳山市、临沂、德州、聊城、菏泽、滨州、章丘、胶南、胶州、平度、莱西、即墨、滕州、龙口、莱阳、莱州、招远、蓬莱、栖霞、海阳、青州、诸城、安丘、高密、昌邑、兖州、曲阜、邹城、乳山、文登、荣成、乐陵、临清、禹城'
        str11 = '江苏：南京、镇江、常州、无锡、苏州、沭阳、徐州、连云港、淮安、盐城、扬州、泰州、南通、沛县、如东县宿迁、江阴市、宜兴市、邳州市、新沂市、金坛市、溧阳市、常熟市、张家港市、太仓市、昆山市、吴江市、如皋市、通州市、海门市、启东市、东台市、大丰市、高邮市、江都市、仪征市、丹阳市、扬中市、句容市、泰兴市、姜堰市、靖江市、兴化市'
        str12 = '安徽：合肥、蚌埠、芜湖、淮南、亳州、阜阳、六安、淮北、宿州、滁州、霍邱、安庆、巢湖、马鞍山、宣城、黄山、池州、铜陵、界首市、天长、明光、桐城、宁国市'
        str13 = '浙江：杭州、嘉兴、湖州、宁波、金华、温州、丽水、绍兴、衢州、舟山、台州、建德市、富阳市、临安市、余姚市、慈溪市、奉化市、瑞安市、淳安县、德清县、横店、嘉善县、永嘉县、乐清市、海宁市、平湖市、桐乡市、诸暨市、上虞市、嵊州市、兰溪市、义乌市、东阳市、永康市、江山市、临海市、温岭市、龙泉市'
        str14 = '福建：福州、厦门、泉州、三明、南平、漳州、莆田、宁德、龙岩、福清市、长乐市、永安市、石狮市、晋江市、南安市、龙海市、邵武市、武夷山、建瓯市、建阳市、漳平市、福安市、福鼎市'
        str15 = '广东：广州、深圳、顺德、汕头、惠州、惠阳、珠海、雷州、揭阳、佛山、河源、阳江、茂名、湛江、梅州、肇庆、韶关、潮州、东莞、中山、清远、江门、汕尾、云浮、增城市、从化市、乐昌市、南雄市、台山市、开平市、鹤山市、恩平市、廉江市、雷州市 、吴川市、高州市、化州市、高要市、四会市、兴宁市、陆丰市、阳春市、英德市、连州市、普宁市、罗定市，信宜市'
        str16 = '海南：海口、三亚、琼海、文昌、万宁、五指山、儋州、东方'
        str17 = '云南：昆明、曲靖、玉溪、保山、昭通、丽江、德宏、普洱、临沧、文山、西双版纳、安宁市、宣威市、个旧市、开远市、景洪市、楚雄市、大理市、潞西市、瑞丽市'
        str18 = '贵州：贵阳、六盘水、遵义、安顺、清镇市、赤水市、仁怀市、铜仁市、毕节市、黔南、兴义市、凯里市、都匀市、福泉市'
        str19 = '四川：成都、绵阳、德阳、广元、自贡、攀枝花、乐山、凉山、南充、内江、遂宁、广安、泸州、双流区、达州、眉山、宜宾、雅安、资阳、都江堰市、彭州市、邛崃市、崇州市、广汉市、什邡市、绵竹市、江油市、峨眉山市、阆中市、华蓥市、万源市、简阳市、西昌市'
        str20 = '湖南：长沙、株洲、湘潭、衡阳、岳阳、郴州、永州、邵阳、怀化、常德、益阳、张家界、娄底、浏阳市、醴陵市、湘乡市、韶山市、耒阳市、常宁市、武冈市、临湘市、汨罗市、津市市、沅江市、资兴市、洪江市、冷水江市、涟源市、吉首市'
        str21 = '湖北：武汉、襄樊、宜昌、黄石、神农架、鄂州、随州、荆州、襄阳、荆门、十堰、孝感、黄冈、咸宁、大冶市、丹江口市、洪湖市、石首市、松滋市、宜都市、当阳市、枝江市、老河口市、枣阳市、宜城市、钟祥市、应城市、安陆市、汉川市、麻城市、武穴市、赤壁市、广水市、仙桃市、天门市、潜江市、恩施市、利川市'
        str22 = '河南：郑州、洛阳、开封、漯河、安阳、新乡、周口、三门峡、焦作、鄢陵、平顶山、信阳、南阳、鹤壁、濮阳、许昌、商丘、驻马店、巩义市、新郑市、新密市、登封市、荥阳市、偃师市、汝州市、舞钢市、林州市、卫辉市、辉县市、沁阳市、孟州市、禹州市、长葛市、义马市、灵宝市、邓州市、永城市、项城市、济源市'
        str23 = '山西：太原、大同、忻州、阳泉、长治、晋城、朔州、晋中、运城、临汾、临猗、清徐、侯马市、吕梁、古交、汾阳市、潞城市、高平、介休、永济市、河津、原平、侯马、霍州市、孝义'
        str24 = '陕西：西安、咸阳、铜川、延安、宝鸡、渭南、汉中、安康、商洛、榆林、兴平市、韩城市、华阴市'
        str25 = '甘肃：兰州、天水、平凉、酒泉、嘉峪关、金昌、白银、武威、张掖、庆阳、定西、陇南、玉门市、敦煌市、临夏市、合作市'
        str26 = '青海：西宁、格尔木市、德令哈市'
        str27 = '江西：南昌、九江、赣州、吉安、鹰潭、上饶、萍乡、景德镇、新余、宜春、抚州、乐平市、瑞昌市、贵溪市、瑞金市、玉山县、南康市、井冈山市、丰城市、樟树市、高安市、德兴市'
        str28 = '台湾：台北、台中、基隆、高雄、台南、新竹、嘉义、板桥市、宜兰市、竹北市、桃园市、苗栗市、丰原市、彰化市、南投市、太保市、斗六市、新营市、凤山市、屏东市、台东市、花莲市、马公市'
        str29 = '香港：香港'
        str30 = '澳门：澳门'
        str31 = '北京：北京市'
        str32 = '上海：上海市'
        str33 = '天津：天津市'
        str34 = '重庆：重庆市'
        list.append(str1)
        list.append(str2)
        list.append(str3)
        list.append(str4)
        list.append(str5)
        list.append(str6)
        list.append(str7)
        list.append(str8)
        list.append(str9)
        list.append(str10)
        list.append(str11)
        list.append(str12)
        list.append(str13)
        list.append(str14)
        list.append(str15)
        list.append(str16)
        list.append(str17)
        list.append(str18)
        list.append(str19)
        list.append(str20)
        list.append(str21)
        list.append(str22)
        list.append(str23)
        list.append(str24)
        list.append(str25)
        list.append(str26)
        list.append(str27)
        list.append(str28)
        list.append(str29)
        list.append(str30)
        list.append(str31)
        list.append(str32)
        list.append(str33)
        list.append(str34)
        self.list = list

    def Process(self, city):
        country = '中国'
        for i in range(0, 34):
            str = self.list[i]
            if city in str:
                if '：' in str:
                    province = str.split('：')[0];
                    ss = str.split('：')[1];
                    split = ss.split('、');
                    for j in range(len(split)):
                        s = split[j]
                        if city in s:
                            if city == s:
                                return country + ' ' + province + ' ' + split[j]
                            else:
                                ssss = s[:-1]
                                if city == ssss:
                                    return country + ' ' + province + ' ' + split[j]
        return ''

    def getProvince(self, city):
        str = self.Process(city)
        if str is not '':
            province = str.split(' ')[1]
            if ("北京" in province) or ("上海" in province) or ("重庆" in province) or ("天津" in province):
                province = province + "市"
            elif ("香港" in province) or ("澳门" in province):
                province = province + "特别行政区"
            elif ("内蒙古" in province) or ("宁夏" in province) or ("新疆" in province) or ("西藏" in province) or (
                    "广西" in province) or ("自治区" in province):
                if ("内蒙古" in province) or ("西藏" in province):
                    province = province + "自治区";
                if "宁夏" in province:
                    province = province + "回族自治区";
                if "新疆" in province:
                    province = province + "维吾尔自治区";
                if "广西" in province:
                    province = province + "壮族自治区";
            else:
                province = province + "省"
            return province
        return ''


if __name__ == '__main__':
    city = '新疆'
    s = ProcessInformation()
    province = s.getProvince(city)
    print(province)
